summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJon Marius Venstad <venstad@gmail.com>2021-07-07 15:09:59 +0200
committerJon Marius Venstad <venstad@gmail.com>2021-07-07 15:09:59 +0200
commitfe0939622a6b234040552bed7125ee1de1135714 (patch)
treed5fb9db9f132511a90cf0862d41ab8fa95f8d022
parent4d1fdcc05aa3243753d4e33a316dbc35c8119979 (diff)
Middle of the night was moved back one hour—update test expectation
-rw-r--r--controller-server/src/test/java/com/yahoo/vespa/hosted/controller/maintenance/DeploymentUpgraderTest.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/maintenance/DeploymentUpgraderTest.java b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/maintenance/DeploymentUpgraderTest.java
index 552a38e6678..7a8f775e8b1 100644
--- a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/maintenance/DeploymentUpgraderTest.java
+++ b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/maintenance/DeploymentUpgraderTest.java
@@ -63,19 +63,19 @@ public class DeploymentUpgraderTest {
assertEquals(start, tester.jobs().last(devApp.instanceId(), devUsEast1).get().start());
assertEquals(start, tester.jobs().last(prodApp.instanceId(), productionUsWest1).get().start());
- // 13 hours pass, but not upgraded before a day has passed since last deployment
- tester.clock().advance(Duration.ofHours(13));
+ // 14 hours pass, but not upgraded before a day has passed since last deployment
+ tester.clock().advance(Duration.ofHours(14));
upgrader.maintain();
assertEquals(start, tester.jobs().last(devApp.instanceId(), devUsEast1).get().start());
assertEquals(start, tester.jobs().last(prodApp.instanceId(), productionUsWest1).get().start());
- // 34 hours pass, but not upgraded since it's not likely in the middle of the night
+ // 35 hours pass, but not upgraded since it's not likely in the middle of the night
tester.clock().advance(Duration.ofHours(21));
upgrader.maintain();
assertEquals(start, tester.jobs().last(devApp.instanceId(), devUsEast1).get().start());
assertEquals(start, tester.jobs().last(prodApp.instanceId(), productionUsWest1).get().start());
- // 37 hours pass, and the dev deployment, only, is upgraded
+ // 38 hours pass, and the dev deployment, only, is upgraded
tester.clock().advance(Duration.ofHours(3));
upgrader.maintain();
assertEquals(tester.clock().instant().truncatedTo(MILLIS), tester.jobs().last(devApp.instanceId(), devUsEast1).get().start());